@@ -41,6 +41,26 @@ This is what happens under the hood:
    `websiteBucket`). If there is more than one source, the sources will be
    downloaded and merged pre-deployment at this step.
 
+If you are referencing the filled bucket in another construct that depends on
+the files already be there, be sure to use `deployment.deployedBucket`. This
+will ensure the bucket deployment has finished before the resource that uses
+the bucket is created:
+
+```python
+# website_bucket: s3.Bucket
+
+
+deployment = s3deploy.BucketDeployment(self, "DeployWebsite",
+    sources=[s3deploy.Source.asset(path.join(__dirname, "my-website"))],
+    destination_bucket=website_bucket
+)
+
+ConstructThatReadsFromTheBucket(self, "Consumer", {
+    # Use 'deployment.deployedBucket' instead of 'websiteBucket' here
+    "bucket": deployment.deployed_bucket
+})
+```
+
 ## Supported sources
 
 The following source types are supported for bucket deployments:
@@ -307,7 +327,7 @@ substituting it when its deployed to the destination with the actual value.
 
 ## Notes
 
-* This library uses an AWS CloudFormation custom resource which about 10MiB in
+* This library uses an AWS CloudFormation custom resource which is about 10MiB in
   size. The code of this resource is bundled with this library.
 * AWS Lambda execution time is limited to 15min. This limits the amount of data
   which can be deployed into the bucket by this timeout.
@@ -371,18 +391,18 @@ class BucketDeployment(
 
     Example::
 
-        # destination_bucket: s3.Bucket
-        # vpc: ec2.Vpc
+        # website_bucket: s3.Bucket
         
         
-        s3deploy.BucketDeployment(self, "DeployMeWithEfsStorage",
+        deployment = s3deploy.BucketDeployment(self, "DeployWebsite",
             sources=[s3deploy.Source.asset(path.join(__dirname, "my-website"))],
-            destination_bucket=destination_bucket,
-            destination_key_prefix="efs/",
-            use_efs=True,
-            vpc=vpc,
-            retain_on_delete=False
+            destination_bucket=website_bucket
         )
+        
+        ConstructThatReadsFromTheBucket(self, "Consumer", {
+            # Use 'deployment.deployedBucket' instead of 'websiteBucket' here
+            "bucket": deployment.deployed_bucket
+        })
     '''
 
     def __init__(
@@ -484,6 +504,19 @@ class BucketDeployment(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="deployedBucket")
+    def deployed_bucket(self) -> aws_cdk.aws_s3.IBucket:
+        '''The bucket after the deployment.
+
+        If you want to reference the destination bucket in another construct and make sure the
+        bucket deployment has happened before the next operation is started, pass the other construct
+        a reference to ``deployment.deployedBucket``.
+
+        Doing this replaces calling ``otherResource.node.addDependency(deployment)``.
+        '''
+        return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "deployedBucket"))
+
 
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-s3-deployment.BucketDeploymentProps",
@@ -587,18 +620,18 @@ class BucketDeploymentProps:
 
         Example::
 
-            # destination_bucket: s3.Bucket
-            # vpc: ec2.Vpc
+            # website_bucket: s3.Bucket
             
             
-            s3deploy.BucketDeployment(self, "DeployMeWithEfsStorage",
+            deployment = s3deploy.BucketDeployment(self, "DeployWebsite",
                 sources=[s3deploy.Source.asset(path.join(__dirname, "my-website"))],
-                destination_bucket=destination_bucket,
-                destination_key_prefix="efs/",
-                use_efs=True,
-                vpc=vpc,
-                retain_on_delete=False
+                destination_bucket=website_bucket
             )
+            
+            ConstructThatReadsFromTheBucket(self, "Consumer", {
+                # Use 'deployment.deployedBucket' instead of 'websiteBucket' here
+                "bucket": deployment.deployed_bucket
+            })
         '''
         if isinstance(metadata, dict):
             metadata = UserDefinedObjectMetadata(**metadata)
@@ -1306,18 +1339,18 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
 
     Example::
 
-        # destination_bucket: s3.Bucket
-        # vpc: ec2.Vpc
+        # website_bucket: s3.Bucket
         
         
-        s3deploy.BucketDeployment(self, "DeployMeWithEfsStorage",
+        deployment = s3deploy.BucketDeployment(self, "DeployWebsite",
             sources=[s3deploy.Source.asset(path.join(__dirname, "my-website"))],
-            destination_bucket=destination_bucket,
-            destination_key_prefix="efs/",
-            use_efs=True,
-            vpc=vpc,
-            retain_on_delete=False
+            destination_bucket=website_bucket
         )
+        
+        ConstructThatReadsFromTheBucket(self, "Consumer", {
+            # Use 'deployment.deployedBucket' instead of 'websiteBucket' here
+            "bucket": deployment.deployed_bucket
+        })
     '''
 
     @jsii.member(jsii_name="asset") # type: ignore[misc]
